@@ -273,6 +273,10 @@ KateView::~KateView()
   // invalidate update signal
   m_delayedUpdateTriggered = false;
 
+  // remove from xmlgui factory, to be safe
+  if (factory())
+    factory()->removeClient (this);
+  
     KTextEditor::ViewBarContainer *viewBarContainer=qobject_cast<KTextEditor::ViewBarContainer*>( KateGlobal::self()->container() );
     if (viewBarContainer) {
      viewBarContainer->deleteViewBarForView(this,KTextEditor::ViewBarContainer::BottomBar);
@@ -1448,10 +1452,9 @@ void KateView::switchToConsole ()
     m_console = new KateScriptConsole (this, bottomViewBar());
     bottomViewBar()->addBarWidget(m_console);
     bottomViewBar()->showBarWidget(m_console);
-  } else {
+  } else
     bottomViewBar()->showBarWidget(m_console);
-    m_console->setupLayout();
-  }
+  m_console->setupLayout();
   m_console->setFocus ();
   hideViModeBar();
 }
@@ -2650,6 +2653,7 @@ KateViModeBar *KateView::viModeBar()
 {
   if (!m_viModeBar) {
     m_viModeBar = new KateViModeBar(this);
+    m_viModeBar->hide ();
   }
 
   return m_viModeBar;
